@@ -31,16 +31,16 @@ Example::
     [...]
 """
 
-import logging
 import time
 import json
 
+import logbook
 import requests
 import pexpect
 
 import conn
 
-logger = logging.getLogger(__name__)
+logger = logbook.Logger(__name__)
 
 ############
 #
@@ -88,12 +88,11 @@ class Device(object):
 
         :param name: Device name for logging purposes.
         """
-        self._logger = logging.getLogger("Device")
         self.conns = kwargs.pop("conns", list(args))
         self._conns_dict = {}
         self.name = kwargs.pop("name", self.__class__.__name__)
         self.prompt = PromptReplacement()
-        self._logger = logging.getLogger(self.name)
+        self._logger = logbook.Logger(self.name)
 
     def cmd(self, msg, expect=None, timeout=30, login_timeout=None, do_retcode=True):
         """ Send a :term:`shell command` to the :term:`target device`.
@@ -174,27 +173,33 @@ class Hydra(Device):
     """ is the device type of DResearch Fahrzeugelektronik GmbH.
     """
 
-    def update(self, link=None, force=None):
+    def update(self, link=None):
         """ update the device to current build from Jenkins.
         """
         self._logger.info("Attempt update to " + str(link or self._update_link))
         if not self.do_update:
             self.log("don't update due to MONK configuration")
             return
-        connection_closed = (pexpect.EOF, pexpect.TIMEOUT)
-        if not self.is_updated or force:
+        if not self.is_updated:
             _, out = self.cmd("do-update -c && get-update {} && do-update".format(
                     link if link else self._update_link,
-                ), expect=("[lL]ogin: ",) +  connection_closed,
+                ), expect="([lL]ogin: )|([cC]onnection\sto\s[^\s]*\sclosed\.)",
                 timeout=600,
                 do_retcode=False,
             )
-            if self.conns[0].exp.after in connection_closed:
+            if "closed" in self.conns[0].exp.after:
                 self.log("reset connection after reboot")
                 del self.conns[0]._exp
             self.log("wait till device recovered from updating")
             time.sleep(240)
             self.log("continue")
+            if not self.is_updated:
+                error= "build:{};fw:{};out:{}".format(
+                        self.latest_build,
+                        self.current_fw_version,
+                        out[:100],
+                )
+                raise UpdateFailedException(error)
         else:
             self._logger.info("Already updated.")
 
@@ -224,7 +229,7 @@ class Hydra(Device):
     def has_newest_firmware(self):
         """ check whether the installed firmware is the newest on jenkins
         """
-        return str(self.latest_build) in str(self.current_fw_version)
+        return self.latest_build in self.current_fw_version
 
     @property
     def is_updated(self):
